==> owncloud-9.0.3.tgz: owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Sharing" : "Chia sẻ",
    "External Storage" : "Lưu trữ ngoài",
    "Cron" : "Cron",
    "Log" : "Log",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Authentication error" : "Lỗi xác thực",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Unable to add user to group %s" : "Không thể thêm người dùng vào nhóm %s",
    "Unable to remove user from group %s" : "Không thể xóa người dùng từ nhóm %s",
    "Couldn't update app." : "Không thể cập nhật ứng dụng",
    "Enabled" : "Bật",
    "Saved" : "Đã lưu",
    "Email sent" : "Email đã được gửi",
    "Email saved" : "Lưu email",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "All" : "Tất cả",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "__language_name__" : "__Ngôn ngữ___",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "More" : "hơn",
    "Less" : "ít",
    "Version" : "Phiên bản",
    "Cheers!" : "Chúc mừng!",
    "Forum" : "Diễn đàn",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Username" : "Tên đăng nhập",
    "Create" : "Tạo",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Unlimited" : "Không giới hạn",
    "Other" : "Khác",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Lỗi xác thực",
    "Saved" : "Đã lưu",
    "Email sent" : "Email đã được gửi",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "__language_name__" : "__Ngôn ngữ___",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "All" : "Tất cả",
    "Enabled" : "Bật",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Select a profile picture" : "Chọn một ảnh hồ sơ",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "Cheers!" : "Chúc mừng!",
    "Forum" : "Diễn đàn",
    "Cron" : "Cron",
    "Open documentation" : "Mở tài liệu",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Sharing" : "Chia sẻ",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Log" : "Log",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Profile picture" : "Ảnh hồ sơ",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Choose as profile picture" : "Chọn hình ảnh làm ảnh hồ sơ",
    "Full name" : "Họ và tên",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Unlimited" : "Không giới hạn",
    "Sessions" : "Phiên làm việc",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Danh sách các thiết bị điện thoại, web và máy tính hiện tại đã đăng nhập vào ownCould của bạn.",
    "Browser" : "Trình duyệt",
    "Most recent activity" : "Hoạt động gần đây nhất",
    "Name" : "Tên",
    "Username" : "Tên đăng nhập",
    "Version" : "Phiên bản",
    "Personal" : "Cá nhân",
    "Admin" : "Quản trị",
    "Error" : "Lỗi",
    "Create" : "Tạo",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Other" : "Khác",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định"
},
"nplurals=1; plural=0;");
